| /freebsd/crypto/openssl/crypto/sm4/asm/ |
| H A D | vpsm4-armv8.pl | 110 sub transpose() { subroutine 944 &transpose(@vtmp,@datax); 945 &transpose(@data,@datax); 982 &transpose(@vtmp,@datax); 1024 &transpose(@vtmp,@datax); 1043 &transpose(@vtmp,@datax); 1330 &transpose(@data,@vtmp); 1331 &transpose(@datax,@vtmp); 1335 &transpose(@vtmp,@datax); 1336 &transpose(@data,@datax); [all …]
|
| H A D | vpsm4_ex-armv8.pl | 113 sub transpose() { subroutine 943 &transpose(@vtmp,@datax); 944 &transpose(@data,@datax); 981 &transpose(@vtmp,@datax); 1023 &transpose(@vtmp,@datax); 1042 &transpose(@vtmp,@datax); 1339 &transpose(@data,@vtmp); 1340 &transpose(@datax,@vtmp); 1344 &transpose(@vtmp,@datax); 1345 &transpose(@data,@datax); [all …]
|
| /freebsd/contrib/llvm-project/clang/include/clang/Basic/ |
| H A D | BuiltinsX86_64.td | 242 let Features = "amx-transpose", Attributes = [NoThrow] in { 246 let Features = "amx-movrs,amx-transpose", Attributes = [NoThrow] in { 250 let Features = "amx-transpose", Attributes = [NoThrow] in { 254 let Features = "amx-movrs,amx-transpose", Attributes = [NoThrow] in { 258 let Features = "amx-transpose", Attributes = [NoThrow] in { 262 let Features = "amx-movrs,amx-transpose", Attributes = [NoThrow] in { 266 let Features = "amx-transpose", Attributes = [NoThrow] in { 270 let Features = "amx-movrs,amx-transpose", Attributes = [NoThrow] in { 274 let Features = "amx-transpose", Attributes = [NoThrow] in { 278 let Features = "amx-bf16,amx-transpose", Attributes = [NoThrow] in { [all …]
|
| H A D | BuiltinsAMDGPU.def | 649 TARGET_BUILTIN(__builtin_amdgcn_global_load_tr4_b64_v2i32, "V2iV2i*1", "nc", "transpose-load-f4f6-i… 651 TARGET_BUILTIN(__builtin_amdgcn_global_load_tr6_b96_v3i32, "V3iV3i*1", "nc", "transpose-load-f4f6-i… 655 TARGET_BUILTIN(__builtin_amdgcn_ds_load_tr4_b64_v2i32, "V2iV2i*3", "nc", "transpose-load-f4f6-insts… 657 TARGET_BUILTIN(__builtin_amdgcn_ds_load_tr6_b96_v3i32, "V3iV3i*3", "nc", "transpose-load-f4f6-insts…
|
| /freebsd/contrib/llvm-project/llvm/include/llvm/CodeGen/PBQP/ |
| H A D | ReductionRules.h | 97 new Matrix(G.getEdgeCosts(YXEId).transpose()) : in applyR2() 101 new Matrix(G.getEdgeCosts(ZXEId).transpose()) : in applyR2() 138 G.updateEdgeCosts(YZEId, Delta.transpose() + YZECosts); in applyR2()
|
| H A D | Math.h | 194 Matrix transpose() const { in transpose() function
|
| /freebsd/crypto/openssl/crypto/chacha/asm/ |
| H A D | chacha-armv8-sve.pl | 289 sub transpose() { subroutine 426 &transpose($xa0,$xa1,$xa2,$xa3,$xb0,$xb1,$xb2,$xb3); 430 &transpose($xc0,$xc1,$xc2,$xc3,$xd0,$xd1,$xd2,$xd3); 512 &transpose($xa0,$xb0,$xc0,$xd0,$xa1,$xb1,$xc1,$xd1); 515 &transpose($xa2,$xb2,$xc2,$xd2,$xa3,$xb3,$xc3,$xd3); 518 &transpose($xa0,$xa1,$xa2,$xa3,$xb0,$xb1,$xb2,$xb3); 521 &transpose($xc0,$xc1,$xc2,$xc3,$xd0,$xd1,$xd2,$xd3);
|
| /freebsd/contrib/byacc/ |
| H A D | lalr.c | 13 static Value_t **transpose(Value_t **R, int n); 426 new_includes = transpose(includes, ngotos); in build_relations() 466 transpose(Value_t **R2, int n) in transpose() function
|
| /freebsd/contrib/tcsh/ |
| H A D | dot.tcshrc | 87 # Set status to ^G in order to keep using ^T for transpose-char.
|
| /freebsd/contrib/llvm-project/llvm/include/llvm/TargetParser/ |
| H A D | X86TargetParser.def | 269 X86_FEATURE (AMX_TRANSPOSE, "amx-transpose")
|
| /freebsd/contrib/llvm-project/llvm/lib/Target/X86/ |
| H A D | X86.td | 274 def FeatureAMXTRANSPOSE : SubtargetFeature<"amx-transpose", "HasAMXTRANSPOSE", "true", 275 "Support AMX amx-transpose instructions",
|
| /freebsd/contrib/llvm-project/llvm/lib/Target/AArch64/ |
| H A D | AArch64SchedThunderX3T110.td | 1638 // ASIMD transpose 1682 // ASIMD transpose
|
| H A D | AArch64SchedNeoverseV1.td | 1120 // ASIMD transpose 1460 // Predicate transpose
|
| H A D | AArch64SchedAmpere1.td | 1136 // -- transpose
|
| H A D | AArch64SchedAmpere1B.td | 1143 // -- transpose
|
| H A D | AArch64SchedNeoverseN2.td | 1224 // ASIMD transpose 1608 // Predicate transpose
|
| H A D | AArch64SchedNeoverseN3.td | 1186 // ASIMD transpose 1578 // Predicate transpose
|
| H A D | AArch64SchedNeoverseN1.td | 760 // ASIMD transpose
|
| H A D | AArch64SchedNeoverseV2.td | 1700 // ASIMD transpose 2093 // Predicate transpose
|
| H A D | AArch64SchedA510.td | 622 // Predicate transpose
|
| H A D | AArch64SchedA320.td | 644 // Predicate transpose
|
| /freebsd/crypto/openssl/doc/designs/quic-design/ |
| H A D | connection-state-machine.md | 495 We transpose the above table to sort by events rather than states, to discern
|
| /freebsd/crypto/heimdal/ |
| H A D | ChangeLog.2001 | 685 * lib/krb5/cache.c (krb5_cc_next_cred): transpose last two
|
| /freebsd/contrib/llvm-project/llvm/lib/Target/ARM/ |
| H A D | ARMScheduleA57.td | 1239 // ASIMD transpose
|
| /freebsd/contrib/llvm-project/llvm/lib/Target/AMDGPU/ |
| H A D | AMDGPU.td | 1115 def FeatureTransposeLoadF4F6Insts : SubtargetFeature<"transpose-load-f4f6-insts",
|